@@ -1,13 +1,13 @@
 import unittest
 from dataclasses import dataclass, field
 
-from keewee import KeeWee
+from src import KeeWee
 
 
 @dataclass
 class PokemonTrainer:
     name: str
-    skill_level: int | KeeWee = field(default=KeeWee(), repr=False)
+    skill_level: int | KeeWee = field(default=KeeWee(blame=True), repr=False)
 
 
 class MyTestCase(unittest.TestCase):
@@ -22,6 +22,7 @@ class MyTestCase(unittest.TestCase):
         self.assertEqual(andrew.skill_level, 1)
 
         ash = PokemonTrainer(name="Ash Ketchum", skill_level=0)
+        ash.name = "Erik"
 
         import random
         for _ in range(4):
